==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/CustomRuleListArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines contents of custom rules
 * @property rules List of rules
 */
public data class CustomRuleListArgs(
    public val rules: Output<List<CustomRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs =
        com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs.builder()
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [CustomRuleListArgs].
 */
@PulumiTagMarker
public class CustomRuleListArgsBuilder internal constructor() {
    private var rules: Output<List<CustomRuleArgs>>? = null

    /**
     * @param value List of rules
     */
    @JvmName("krbwwscbokodrcdv")
    public suspend fun rules(`value`: Output<List<CustomRuleArgs>>) {
        this.rules = value
    }

    @JvmName("boblqflgwdppwyci")
    public suspend fun rules(vararg values: Output<CustomRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values List of rules
     */
    @JvmName("tqxdhtfesfluyrhk")
    public suspend fun rules(values: List<Output<CustomRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value List of rules
     */
    @JvmName("xloxoukvbbrrmhky")
    public suspend fun rules(`value`: List<CustomRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument List of rules
     */
    @JvmName("nfooejrbbhmjsccu")
    public suspend fun rules(argument: List<suspend CustomRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { CustomRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules
     */
    @JvmName("hrjoxcnambbkxvhp")
    public suspend fun rules(vararg argument: suspend CustomRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { CustomRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules
     */
    @JvmName("qksdckjedhumihuq")
    public suspend fun rules(argument: suspend CustomRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(CustomRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values List of rules
     */
    @JvmName("kecfnfnliakliwou")
    public suspend fun rules(vararg values: CustomRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): CustomRuleListArgs = CustomRuleListArgs(
        rules = rules,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/CustomRuleListArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines contents of custom rules
 * @property rules List of rules
 */
public data class CustomRuleListArgs(
    public val rules: Output<List<CustomRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs =
        com.pulumi.azurenative.cdn.inputs.CustomRuleListArgs.builder()
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [CustomRuleListArgs].
 */
@PulumiTagMarker
public class CustomRuleListArgsBuilder internal constructor() {
    private var rules: Output<List<CustomRuleArgs>>? = null

    /**
     * @param value List of rules
     */
    @JvmName("vxcngehcvexibkyr")
    public suspend fun rules(`value`: Output<List<CustomRuleArgs>>) {
        this.rules = value
    }

    @JvmName("wgajhuthietdolak")
    public suspend fun rules(vararg values: Output<CustomRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values List of rules
     */
    @JvmName("ytccstobyyrjulld")
    public suspend fun rules(values: List<Output<CustomRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value List of rules
     */
    @JvmName("odpxieucdabruxec")
    public suspend fun rules(`value`: List<CustomRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument List of rules
     */
    @JvmName("gxuyolpmegbhkeyp")
    public suspend fun rules(argument: List<suspend CustomRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { CustomRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules
     */
    @JvmName("opcikgxdwnspvokq")
    public suspend fun rules(vararg argument: suspend CustomRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { CustomRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument List of rules
     */
    @JvmName("fojtexcsuubttbkb")
    public suspend fun rules(argument: suspend CustomRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(CustomRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values List of rules
     */
    @JvmName("cdttinafhpkiictm")
    public suspend fun rules(vararg values: CustomRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): CustomRuleListArgs = CustomRuleListArgs(
        rules = rules,
    )
}
